Simple test
------------

Ensure your image loads with this simple test.

.. literalinclude:: ../examples/imageload_simpletest.py
    :caption: examples/imageload_simpletest.py
    :linenos:

Requests test
-------------

Loads image that is fetched using adafruit_request

.. literalinclude:: ../examples/imageload_from_web.py
    :caption: examples/imageload_from_web.py
    :linenos:
